@@ -62,8 +62,8 @@ bonono_config_bag_get_properties (BonoboConfigBag   *cb,
 		plist->_buffer [plist->_length++] = obj;
 	}
 
-	// fixme:
-	// CORBA_free (key_list);
+	/* fixme: */
+	/* CORBA_free (key_list); */
 
 	return plist;
 }
@@ -126,6 +126,17 @@ static void
 bonobo_config_bag_destroy (GtkObject *object)
 {
 	BonoboConfigBag *cb = BONOBO_CONFIG_BAG (object);
+	CORBA_Environment ev;
+
+	if (cb->listener_id != 0) {
+		CORBA_exception_init (&ev);
+		bonobo_event_source_client_remove_listener (cb->db, cb->listener_id, &ev);
+
+		if (BONOBO_EX (&ev))
+			g_critical ("Could not remove listener (%s)", bonobo_exception_get_text (&ev));
+
+		CORBA_exception_free (&ev);
+	}
 	
 	if (cb->transient)
 		gtk_object_unref (GTK_OBJECT (cb->transient));
@@ -254,7 +265,7 @@ bonobo_config_bag_new (Bonobo_ConfigDatabase db,
 
 	m = g_strconcat ("Bonobo/ConfigDatabase:change", cb->path, ":", NULL);
 
-	bonobo_event_source_client_add_listener (db, notify_cb, m, NULL, cb);
+	cb->listener_id = bonobo_event_source_client_add_listener (db, notify_cb, m, NULL, cb);
 
 	g_free (m);
 
@@ -290,7 +301,7 @@ bonobo_config_bag_class_init (BonoboConfigBagClass *class)
 static void
 bonobo_config_bag_init (BonoboConfigBag *cb)
 {
-	/* nothing to do */
+	cb->listener_id = 0;
 }
 
 BONOBO_X_TYPE_FUNC_FULL (BonoboConfigBag, 
