@@ -732,8 +732,11 @@ bonobo_config_get_value  (Bonobo_ConfigDatabase  db,
 
 	if (BONOBO_EX (my_ev)) {
 		if (!opt_ev) {
-			g_warning ("Cannot get value: %s\n", 
-				   bonobo_exception_get_text (my_ev));
+			char *err;
+
+			err = bonobo_exception_get_text (my_ev);
+			g_warning ("Cannot get value: %s\n", err);
+			g_free (err);
 			
 			CORBA_exception_free (&ev);
 		}
@@ -762,7 +765,7 @@ bonobo_config_get_value  (Bonobo_ConfigDatabase  db,
 	return retval;
 }
 
-#define MAKE_SET_SIMPLE(c_type, name, corba_tc)                               \
+#define MAKE_SET_SIMPLE(c_type, name, corba_type, corba_tc)                   \
 void bonobo_config_set_##name (Bonobo_ConfigDatabase  db,                     \
 			       const char            *key,                    \
 			       const c_type           value,                  \
@@ -772,7 +775,7 @@ void bonobo_config_set_##name (Bonobo_ConfigDatabase  db,                     \
 	bonobo_return_if_fail (db != CORBA_OBJECT_NIL, opt_ev);               \
 	bonobo_return_if_fail (key != NULL, opt_ev);                          \
 	any = bonobo_arg_new (corba_tc);                                      \
-	*((c_type *)(any->_value)) = value;                                   \
+	*((corba_type *)(any->_value)) = value;                               \
 	bonobo_config_set_value (db, key, any, opt_ev);                       \
 	bonobo_arg_release (any);                                             \
 }
@@ -786,7 +789,7 @@ void bonobo_config_set_##name (Bonobo_ConfigDatabase  db,                     \
  *
  * Set a 16 bit integer value in the configuration database.
  */
-MAKE_SET_SIMPLE (gint16, short, TC_short)
+MAKE_SET_SIMPLE (gint16, short, CORBA_short, TC_short)
 /**
  * bonobo_config_set_ushort:
  * @db: a reference to the database object
@@ -796,7 +799,7 @@ MAKE_SET_SIMPLE (gint16, short, TC_short)
  *
  * Set a 16 bit unsigned integer value in the configuration database.
  */
-MAKE_SET_SIMPLE (guint16, ushort, TC_ushort)
+MAKE_SET_SIMPLE (guint16, ushort, CORBA_unsigned_short, TC_ushort)
 /**
  * bonobo_config_set_long:
  * @db: a reference to the database object
@@ -806,7 +809,7 @@ MAKE_SET_SIMPLE (guint16, ushort, TC_ushort)
  *
  * Set a 32 bit integer value in the configuration database.
  */
-MAKE_SET_SIMPLE (gint32, long, TC_long)
+MAKE_SET_SIMPLE (gint32, long, CORBA_long, TC_long)
 /**
  * bonobo_config_set_ulong:
  * @db: a reference to the database object
@@ -816,7 +819,7 @@ MAKE_SET_SIMPLE (gint32, long, TC_long)
  *
  * Set a 32 bit unsigned integer value in the configuration database.
  */
-MAKE_SET_SIMPLE (guint32, ulong, TC_ulong)
+MAKE_SET_SIMPLE (guint32, ulong, CORBA_unsigned_long, TC_ulong)
 /**
  * bonobo_config_set_float:
  * @db: a reference to the database object
@@ -826,7 +829,7 @@ MAKE_SET_SIMPLE (guint32, ulong, TC_ulong)
  *
  * Set a single precision floating point value in the configuration database.
  */
-MAKE_SET_SIMPLE (gfloat, float, TC_float)
+MAKE_SET_SIMPLE (gfloat, float, CORBA_float, TC_float)
 /**
  * bonobo_config_set_double:
  * @db: a reference to the database object
@@ -836,7 +839,7 @@ MAKE_SET_SIMPLE (gfloat, float, TC_float)
  *
  * Set a double precision floating point value in the configuration database.
  */
-MAKE_SET_SIMPLE (gdouble, double, TC_double)
+MAKE_SET_SIMPLE (gdouble, double, CORBA_double, TC_double)
 /**
  * bonobo_config_set_boolean:
  * @db: a reference to the database object
@@ -846,7 +849,8 @@ MAKE_SET_SIMPLE (gdouble, double, TC_double)
  *
  * Set a boolean value in the configuration database.
  */
-MAKE_SET_SIMPLE (gboolean, boolean, TC_boolean)
+MAKE_SET_SIMPLE (gboolean, boolean, CORBA_boolean, TC_boolean)
+
 /**
  * bonobo_config_set_char:
  * @db: a reference to the database object
@@ -856,7 +860,7 @@ MAKE_SET_SIMPLE (gboolean, boolean, TC_boolean)
  *
  * Set a 8 bit characte value in the configuration database.
  */
-MAKE_SET_SIMPLE (gchar, char, TC_char)
+MAKE_SET_SIMPLE (gchar, char, CORBA_char, TC_char)
 /**
  * bonobo_config_set_string:
  * @db: a reference to the database object
@@ -919,4 +923,3 @@ bonobo_config_set_value  (Bonobo_ConfigDatabase  db,
 	if (!opt_ev)
 		CORBA_exception_free (&ev);
 }
-
